
TODO: TODO_10_72_28_05: Simpler `help` config for any number of commands.

It also applies to `intercept` and `query_.

# The point

Configuring commands like `help`, `intercept`, `enum` is still seems cumbersome and error-prone:

*   The delegators for these funcs has to provide `single_func_id` in their config.

    This is required to find places where these funcs plug into the tree to
    build `tree_abs_path_to_interp_id` from FS_33_76_82_84 composite forest.

*   However, there is no validation whether func from that `single_fund_id` is configured correctly.

    The FS_33_76_82_84 composite forest has to have nested nodes with single function there:

    ```yaml
    "help":
        node_type: interp_tree_node
        plugin_instance_id: FuncTreeInterpFactory.default
        sub_tree:
            "":
                node_type: func_tree_node
                func_id: func_id_help_hint
    ```

    And this config has to be duplicated for all places where "help" is plugged into.

# Why do we need `FuncTreeInterpFactory` interp wrapping single-func sub-tree with single `func_tree_node`?

All funcs are searched within the tree in a standard way:
*   args to the path within a tree can be specified out of order
*   all remaining args are eaten eagerly if possible (without re-querying)

For example, if `lay intercept goto` is specified, and there are some paths with the 2nd step `goto`,
this would select (based on how `intercept` is normally configured) no function - the user interrogation will stop.
This happens because there is no funcs with 1st step `intercept` and 2nd step `goto`.

By using FS_01_89_09_24 interp tree instead of FS_26_43_73_72 func tree,
`intercept` becomes terminal (single) function under interp tree with 1st step `intercept`,
so subsequent `goto` is consumed by next interpreter (which will start from beginning as FS_26_43_73_72 func tree).

It is a bit cumbersome to configure it, but it works as needed.
To be fair, there are not many meta functions like `intercept` or `help` (which also uses that).

See also:
*   TODO_26_08_72_06 interp vs delegator.
*   TODO_06_54_83_58 extend via func instead of delegator
